const analytics = window.ns_.analytics;


// Setup event Listeners
const setupEventListeners = () => {
    window.addEventListener('BACKGROUND_EVENT', function(event) {
        analytics.notifyExitForeground();
    });
    window.addEventListener('FOREGROUND_EVENT', function(event) {
        analytics.notifyEnterForeground();
    });
    window.addEventListener('PIP_ENABLED', function(event) {
        analytics.notifyUxActive();
    });
    window.addEventListener('PIP_DISABLED', function(event) {
        analytics.notifyUxInactive();
    });
}

// Get device info from JS Bridge method
const getDeviceInfo = async () => {
    let deviceInfo = null;
    if (window.miniTVComscoreJsBridge && typeof window.miniTVComscoreJsBridge.getDeviceInfo === 'function') {
        deviceInfo = await JSON.parse(window.miniTVComscoreJsBridge.getDeviceInfo());
    }
    return deviceInfo;
}

// This interface creates a local storage to store session data
function LocalStorage() {
    /**
     * @param {string} settings
     */
    this.storeProperties = function (settings) {
        if (window.miniTVComscoreJsBridge && typeof window.miniTVComscoreJsBridge.storeProperties === 'function') {
            window.miniTVComscoreJsBridge.storeProperties(settings);
        }
    };

    /**
     * @returns {?string}
     */
    this.getProperties = function () {
        if (window.miniTVComscoreJsBridge && typeof window.miniTVComscoreJsBridge.getProperties === 'function') {
            return window.miniTVComscoreJsBridge.getProperties();
        }
    };

    /**
     * @param {string} cache
     */
    this.storeCache = function (cache) {
        if (window.miniTVComscoreJsBridge && typeof window.miniTVComscoreJsBridge.storeCache === 'function') {
            window.miniTVComscoreJsBridge.storeCache(cache);
        }
    };

    /**
     * @returns {?string}
     */
    this.getCache = function () {
        if (window.miniTVComscoreJsBridge && typeof window.miniTVComscoreJsBridge.getCache === 'function') {
            return window.miniTVComscoreJsBridge.getCache();
        }
    };
}

const initialiseComscore = async (deviceInfo) => {
    // This interface defines how data will be fetched by Comscore SDK
    const comscoreDataInterfaceObj = {
        onDataFetch: (onSuccessCallback, onErrorCallback) => {
            if (deviceInfo !== null) {
                onSuccessCallback();
            } else {
                onErrorCallback();
            }
        },
        getDeviceModel: () => {
            return deviceInfo.deviceModel;
        },
        getCrossPublisherUniqueDeviceId: () => {
            return deviceInfo.crossPublisherUniqueDeviceId;
        },
        getPublisherSpecificUniqueDeviceId: () => {
            return deviceInfo.publisherSpecificUniqueDeviceId;
        },
        getPlatformName: () => {
            return deviceInfo.platformName;
        },
        getPlatformVersion: () => {
            return deviceInfo.platformVersion;
        },
        getRuntimeName: () => {
            return deviceInfo.runtimeName;
        },
        getRuntimeVersion: () => {
            return deviceInfo.runtimeVersion;
        },
        getPackageName: () => {
            return deviceInfo.packageName;
        },
        getApplicationVersion: () => {
            return deviceInfo.applicationVersion
        },
        Storage: LocalStorage
    };

    if (typeof analytics !== 'undefined') {
        analytics.PlatformApi.setPlatformApi(analytics.PlatformApi.PlatformApis.Skeleton, comscoreDataInterfaceObj);

        const myPublisherConfig = new analytics.configuration.PublisherConfiguration({
            publisherId: '6034961'
        });

        analytics.configuration.addClient(myPublisherConfig);
        analytics.configuration.setApplicationName("MiniTVStandaloneApp");
        analytics.start();
    }
}

getDeviceInfo().then(deviceInfo => {
    setupEventListeners();
    initialiseComscore(deviceInfo);
})



